@@ -1,4 +1,5 @@
 from .FunctionOperator import FunctionOperator
+from .MemoizeOperator import MemoizeOperator
 from .Regression import Regression
 from .LinearRegression import LinearRegression
 from .MatrixMult import MatrixMult
@@ -13,6 +14,9 @@ from .Transpose import Transpose
 from .Roll import Roll
 from .Pad import Pad
 from .Sum import Sum
+from .Real import Real
+from .Imag import Imag
+from .Conj import Conj
 
 from .VStack import VStack
 from .HStack import HStack
